<?php

namespace MSP\CashOnDelivery\Block\Adminhtml\Order\Creditmemo\View;

use Magento\Framework\Pricing\PriceCurrencyInterface;

class Adjustments extends \Magento\Backend\Block\Template
{
    /**
     * Source object
     *
     * @var \Magento\Framework\DataObject
     */
    protected $_source;

    /**
     * Tax config
     *
     * @var \Magento\Tax\Model\Config
     */
    protected $_taxConfig;

    /**
     * @var PriceCurrencyInterface
     */
    protected $priceCurrency;

    /**
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Tax\Model\Config $taxConfig
     * @param PriceCurrencyInterface $priceCurrency
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Tax\Model\Config $taxConfig,
        PriceCurrencyInterface $priceCurrency,
        array $data = []
    ) {
        $this->_taxConfig = $taxConfig;
        $this->priceCurrency = $priceCurrency;
        parent::__construct($context, $data);
    }

    /**
     * Initialize creditmemo agjustment totals
     *
     * @return $this
     */
    public function initTotals()
    {
        $parent = $this->getParentBlock();
        $this->_source = $parent->getSource();
        $total = new \Magento\Framework\DataObject(['code' => 'agjustments', 'block_name' => $this->getNameInLayout()]);
        $parent->addTotal($total);
        return $this;
    }

    /**
     * Get source object
     *
     * @return \Magento\Framework\DataObject
     */
    public function getSource()
    {
        return $this->_source;
    }

    /**
     * Check if order has gift wrap
     * @return bool|int
     */
    public function orderHasGiftWrap() {
        $giftWrapId = $this->getSource()->getOrder()->getGwId();
        $giftWrapValue = ($this->getSource()->getOrder()->getGwPrice() + $this->getSource()->getOrder()->getGwTaxAmount());
        
        $res = !is_null($giftWrapId) && $giftWrapId > 0 && !is_null($giftWrapValue) && $giftWrapValue > 0;

        if(!$res) {
            if($giftWrapValue === 0) {
                $res = intval(0);
            }
            else {
                $res = false;
            }
        }

        return $res;
    }

    public function getCreditMemoGwValue() {
        $gwValue = $this->getSource()->getGwBasePrice();
        if($gwValue == 0)
        {
            return 0;
        }
        return true;
    }

    public function formatValue($value) {
        return $this->priceCurrency->format($value);
    }
}